import { Construct, IConstruct } from 'constructs';
import { Chart } from './chart';
import { ApiObjectMetadata, ApiObjectMetadataDefinition } from './metadata';
/**
 * (experimental) Options for defining API objects.
 *
 * @experimental
 */
export interface ApiObjectOptions {
    /**
     * (experimental) Object metadata.
     *
     * If `name` is not specified, an app-unique name will be allocated by the
     * framework based on the path of the construct within thes construct tree.
     *
     * @experimental
     */
    readonly metadata?: ApiObjectMetadata;
    /**
     * (experimental) API version.
     *
     * @experimental
     */
    readonly apiVersion: string;
    /**
     * (experimental) Resource kind.
     *
     * @experimental
     */
    readonly kind: string;
    /**
     * Additional attributes for this API object.
     */
    readonly [key: string]: any;
}
/**
 * @experimental
 */
export declare class ApiObject extends Construct {
    private readonly options;
    /**
     * (experimental) The name of the API object.
     *
     * If a name is specified in `metadata.name` this will be the name returned.
     * Otherwise, a name will be generated by calling
     * `Chart.of(this).generatedObjectName(this)`, which by default uses the
     * construct path to generate a DNS-compatible name for the resource.
     *
     * @experimental
     */
    readonly name: string;
    /**
     * (experimental) The object's API version (e.g. `authorization.k8s.io/v1`).
     *
     * @experimental
     */
    readonly apiVersion: string;
    /**
     * (experimental) The group portion of the API version (e.g. `authorization.k8s.io`).
     *
     * @experimental
     */
    readonly apiGroup: string;
    /**
     * (experimental) The object kind.
     *
     * @experimental
     */
    readonly kind: string;
    /**
     * (experimental) The chart in which this object is defined.
     *
     * @experimental
     */
    readonly chart: Chart;
    /**
     * (experimental) Metadata associated with this API object.
     *
     * @experimental
     */
    readonly metadata: ApiObjectMetadataDefinition;
    /**
     * (experimental) Defines an API object.
     *
     * @param scope the construct scope.
     * @param ns namespace.
     * @param options options.
     * @experimental
     */
    constructor(scope: Construct, ns: string, options: ApiObjectOptions);
    /**
     * (experimental) Create a dependency between this ApiObject and other constructs.
     *
     * These can be other ApiObjects, Charts, or custom.
     *
     * @param dependencies the dependencies to add.
     * @experimental
     */
    addDependency(...dependencies: IConstruct[]): void;
    /**
     * (experimental) Renders the object to Kubernetes JSON.
     *
     * @experimental
     */
    toJson(): any;
}
