/**
 * (experimental) Utilities for generating unique and stable names.
 *
 * @experimental
 */
export declare class Names {
    /**
     * (experimental) Generates a unique and stable name compatible DNS_LABEL from RFC-1123 from a path.
     *
     * The generated name will:
     *   - contain at most 63 characters
     *   - contain only lowercase alphanumeric characters or ‘-’
     *   - start with an alphanumeric character
     *   - end with an alphanumeric character
     *
     * The generated name will have the form:
     *   <comp0>-<comp1>-..-<compN>-<short-hash>
     *
     * Where <comp> are the path components (assuming they are is separated by
     * "/").
     *
     * Note that if the total length is longer than 63 characters, we will trim
     * the first components since the last components usually encode more meaning.
     *
     * @param path a path to a node (components separated by "/").
     * @param maxLen maximum allowed length for name.
     * @experimental
     * @link https://tools.ietf.org/html/rfc1123
     * @throws if any of the components do not adhere to naming constraints or
     * length.
     */
    static toDnsLabel(path: string, maxLen?: number): string;
    /**
     * (experimental) Generates a unique and stable name compatible label key name segment and label value from a path.
     *
     * The name segment is required and must be 63 characters or less, beginning
     * and ending with an alphanumeric character ([a-z0-9A-Z]) with dashes (-),
     * underscores (_), dots (.), and alphanumerics between.
     *
     * Valid label values must be 63 characters or less and must be empty or
     * begin and end with an alphanumeric character ([a-z0-9A-Z]) with dashes
     * (-), underscores (_), dots (.), and alphanumerics between.
     *
     * The generated name will have the form:
     *   <comp0><delim><comp1><delim>..<delim><compN><delim><short-hash>
     *
     * Where <comp> are the path components (assuming they are is separated by
     * "/").
     *
     * Note that if the total length is longer than 63 characters, we will trim
     * the first components since the last components usually encode more meaning.
     *
     * @param path a path to a node (components separated by "/").
     * @param delim a delimiter to separates components.
     * @param maxLen maximum allowed length for name.
     * @experimental
     * @link https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#syntax-and-character-set
     * @throws if any of the components do not adhere to naming constraints or
     * length.
     */
    static toLabelValue(path: string, delim?: string, maxLen?: number): string;
    private constructor();
}
